# Security Policy

## Why

This file is being done more for the sake of completion, no real point is being exposed.

## Supported Versions

- **main** branch — under active maintenance  
- Older releases — not supported

## Reporting a Vulnerability

If you discover a security issue in optpricing, please report it privately by emailing  
**DiljitSingh22@googles_emailing_service.com**.
